@@ -32,6 +32,9 @@
 #include <glib/gi18n-lib.h>
 #include <gmodule.h>
 #include <string.h>
+#include <libpeas/peas-extension-base.h>
+#include <libpeas/peas-object-module.h>
+#include <libpeas/peas-activatable.h>
 #include <bacon-video-widget-properties.h>
 
 #include "totem-plugin.h"
@@ -46,7 +49,7 @@
 
 typedef struct
 {
-	TotemPlugin   parent;
+	PeasExtensionBase parent;
 
 	GtkWidget    *props;
 	guint         handler_id_stream_length;
@@ -54,25 +57,18 @@ typedef struct
 
 typedef struct
 {
-	TotemPluginClass parent_class;
+	PeasExtensionBaseClass parent_class;
 } TotemMoviePropertiesPluginClass;
 
-
-G_MODULE_EXPORT GType register_totem_plugin		(GTypeModule *module);
 GType	totem_movie_properties_plugin_get_type		(void) G_GNUC_CONST;
 
-static gboolean impl_activate				(TotemPlugin *plugin, TotemObject *totem, GError **error);
-static void impl_deactivate				(TotemPlugin *plugin, TotemObject *totem);
-
-TOTEM_PLUGIN_REGISTER(TotemMoviePropertiesPlugin, totem_movie_properties_plugin)
+TOTEM_PLUGIN_REGISTER(TOTEM_TYPE_MOVIE_PROPERTIES_PLUGIN,
+		      TotemMoviePropertiesPlugin,
+		      totem_movie_properties_plugin)
 
 static void
 totem_movie_properties_plugin_class_init (TotemMoviePropertiesPluginClass *klass)
 {
-	TotemPluginClass *plugin_class = TOTEM_PLUGIN_CLASS (klass);
-
-	plugin_class->activate = impl_activate;
-	plugin_class->deactivate = impl_deactivate;
 }
 
 static void
@@ -136,14 +132,15 @@ totem_movie_properties_plugin_metadata_updated (TotemObject *totem,
 	g_object_unref (bvw);
 }
 
-static gboolean
-impl_activate (TotemPlugin *plugin,
-	       TotemObject *totem,
-	       GError **error)
+static void
+impl_activate (PeasActivatable *plugin,
+	       GObject *object)
 {
 	TotemMoviePropertiesPlugin *pi;
+	TotemObject *totem;
 
 	pi = TOTEM_MOVIE_PROPERTIES_PLUGIN (plugin);
+	totem = TOTEM_OBJECT (object);
 
 	pi->props = bacon_video_widget_properties_new ();
 	gtk_widget_show (pi->props);
@@ -169,19 +166,27 @@ impl_activate (TotemPlugin *plugin,
 							 "notify::stream-length",
 							 G_CALLBACK (stream_length_notify_cb),
 							 plugin);
-
-	return TRUE;
 }
 
 static void
-impl_deactivate	(TotemPlugin *plugin,
-		 TotemObject *totem)
+impl_deactivate	(PeasActivatable *plugin,
+		 GObject *object)
 {
 	TotemMoviePropertiesPlugin *pi;
+	TotemObject *totem = TOTEM_OBJECT (object);
 
 	pi = TOTEM_MOVIE_PROPERTIES_PLUGIN (plugin);
 
 	g_signal_handler_disconnect (G_OBJECT (totem), pi->handler_id_stream_length);
+	g_signal_handlers_disconnect_by_func (G_OBJECT (totem),
+					      totem_movie_properties_plugin_metadata_updated,
+					      plugin);
+	g_signal_handlers_disconnect_by_func (G_OBJECT (totem),
+					      totem_movie_properties_plugin_file_opened,
+					      plugin);
+	g_signal_handlers_disconnect_by_func (G_OBJECT (totem),
+					      totem_movie_properties_plugin_file_closed,
+					      plugin);
 	pi->handler_id_stream_length = 0;
 	totem_remove_sidebar_page (totem, "properties");
 }
