@@ -31,12 +31,12 @@
 #include <gconf/gconf-client.h>
 #include <gtk/gtk.h>
 #include <gio/gio.h>
-#include <unique/uniqueapp.h>
 
 #include "totem-playlist.h"
 #include "bacon-video-widget.h"
 #include "totem-open-location.h"
 #include "totem-fullscreen.h"
+#include "totem-plugins-engine.h"
 
 #define totem_signal_block_by_data(obj, data) (g_signal_handlers_block_matched (obj, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, data))
 #define totem_signal_unblock_by_data(obj, data) (g_signal_handlers_unblock_matched (obj, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, data))
@@ -69,7 +69,7 @@ typedef enum {
 	STATE_STOPPED
 } TotemStates;
 
-struct TotemObject {
+struct _TotemObject {
 	GObject parent;
 
 	/* Control window */
@@ -95,6 +95,7 @@ struct TotemObject {
 
 	/* Plugins */
 	GtkWidget *plugins;
+	TotemPluginsEngine *engine;
 
 	/* Sidebar */
 	GtkWidget *sidebar;
@@ -158,7 +159,7 @@ struct TotemObject {
 	gint64 seek_to;
 	TotemPlaylist *playlist;
 	GConfClient *gc;
-	UniqueApp *app;
+	GApplication *app;
 	TotemStates state;
 	TotemOpenLocation *open_location;
 	gboolean remember_position;
