@@ -35,6 +35,8 @@
  *
  * #TotemVideoList is a #GtkTreeView designed for listing videos by their thumbnails using #TotemCellRendererVideo.
  * It supports tooltips, loading the videos by activating tree view rows, and #GtkUIManager actions in the popup menu.
+ *
+ * Note that it requires #TotemVideoList:totem to be set to an instance of #TotemObject to work.
  **/
 
 #include "config.h"
@@ -328,7 +330,7 @@ static void
 row_activated_cb (GtkTreeView *tree_view, GtkTreePath *path, GtkTreeViewColumn *column, gpointer user_data)
 {
 	GtkTreeIter iter;
-	gchar *mrl, *display_name;
+	gchar *mrl, *display_name = NULL;
 	gboolean play_video = TRUE;
 	TotemVideoList *self = TOTEM_VIDEO_LIST (tree_view);
 	GtkTreeModel *model = gtk_tree_view_get_model (tree_view);
