@@ -61,11 +61,10 @@
 #define GALLERY_MIN 3				/* minimum number of screenshots in a gallery */
 #define GALLERY_MAX 30				/* maximum number of screenshots in a gallery */
 #define GALLERY_HEADER_HEIGHT 66		/* header height (in pixels) for the gallery */
-#define DEFAULT_OUTPUT_SIZE 128
 
 static gboolean jpeg_output = FALSE;
 static gboolean raw_output = FALSE;
-static int output_size = -1;
+static gboolean output_size = 128;
 static gboolean time_limit = TRUE;
 static gboolean verbose = FALSE;
 static gboolean print_progress = FALSE;
@@ -322,12 +321,10 @@ save_pixbuf (GdkPixbuf *pixbuf, const char *path,
 	height = gdk_pixbuf_get_height (pixbuf);
 	width = gdk_pixbuf_get_width (pixbuf);
 
-	/* If we're outputting a gallery or a raw image without a size,
-	 * don't scale the pixbuf or add borders */
-	if (gallery != -1 || (raw_output != FALSE && size == -1))
+	/* If we're outputting a gallery or a raw image, don't scale the
+	 * pixbuf or add borders */
+	if (gallery != -1 || raw_output)
 		with_holes = g_object_ref (pixbuf);
-	else if (raw_output != FALSE)
-		with_holes = scale_pixbuf (pixbuf, size, TRUE);
 	else
 		with_holes = scale_pixbuf (pixbuf, size, is_still);
 
@@ -428,14 +425,14 @@ static GdkPixbuf *
 capture_frame_at_time(BaconVideoWidget *bvw,
 		      const char *input,
 		      const char *output,
-		      gint64 milliseconds)
+		      gint64 seconds) 
 {
 	GError *err = NULL;
 
-	if (bacon_video_widget_seek_time (bvw, milliseconds, TRUE, &err) == FALSE) {
-		g_print ("totem-video-thumbnailer: could not seek to %d milliseconds in '%s'\n"
+	if (bacon_video_widget_seek_time (bvw, seconds * 1000, TRUE, &err) == FALSE) {
+		g_print ("totem-video-thumbnailer: could not seek to %d seconds in '%s'\n"
 			 "Reason: %s\n",
-			 (int) milliseconds, input, err ? err->message : "programming error");
+			 (int) seconds, input, err ? err->message : "programming error");
 		bacon_video_widget_close (bvw);
 		gtk_widget_destroy (GTK_WIDGET (bvw));
 		g_error_free (err);
@@ -548,12 +545,12 @@ create_gallery (BaconVideoWidget *bvw, const char *input, const char *output)
 	gchar *header_text, *duration_text, *filename;
 
 	/* Calculate how many screenshots we're going to take */
-	stream_length = bacon_video_widget_get_stream_length (bvw);
+	stream_length = bacon_video_widget_get_stream_length (bvw) / 1000;
 
 	/* As a default, we have one screenshot per minute of stream,
 	 * but adjusted so we don't have any gaps in the resulting gallery. */
 	if (gallery == 0) {
-		gallery = stream_length / 60000;
+		gallery = stream_length / 60;
 
 		while (gallery % 3 != 0 &&
 		       gallery % 4 != 0 &&
@@ -568,11 +565,7 @@ create_gallery (BaconVideoWidget *bvw, const char *input, const char *output)
 		gallery = GALLERY_MAX;
 	screenshot_interval = stream_length / gallery;
 
-	/* Put a lower bound on the screenshot interval so we can't enter an infinite loop below */
-	if (screenshot_interval == 0)
-		screenshot_interval = 1;
-
-	PROGRESS_DEBUG ("Producing gallery of %u screenshots, taken at %" G_GINT64_FORMAT " millisecond intervals throughout a %" G_GINT64_FORMAT " millisecond-long stream.",
+	PROGRESS_DEBUG ("Producing gallery of %u screenshots, taken at %" G_GINT64_FORMAT " second intervals throughout a %" G_GINT64_FORMAT " second-long stream.",
 			gallery, screenshot_interval, stream_length);
 
 	/* Calculate how to arrange the screenshots so we don't get ones orphaned on the last row.
@@ -626,7 +619,7 @@ create_gallery (BaconVideoWidget *bvw, const char *input, const char *output)
 				      GDK_INTERP_BILINEAR, 255);
 		g_object_unref (screenshot);
 
-		PROGRESS_DEBUG ("Composited screenshot from %" G_GINT64_FORMAT " milliseconds (address %u) at (%u,%u).",
+		PROGRESS_DEBUG ("Composited screenshot from %" G_GINT64_FORMAT " seconds (address %u) at (%u,%u).",
 				pos, GPOINTER_TO_UINT (screenshot), x, y);
 
 		/* We print progress in the range 10% (MIN_PROGRESS) to 50% (MAX_PROGRESS - MIN_PROGRESS) / 2.0 */
@@ -658,7 +651,7 @@ create_gallery (BaconVideoWidget *bvw, const char *input, const char *output)
 	g_object_unref (pixbuf);
 
 	/* Build the header information */
-	duration_text = totem_time_to_string (stream_length);
+	duration_text = totem_time_to_string (stream_length * 1000);
 	filename = NULL;
 	if (strstr (input, "://")) {
 		char *local;
@@ -713,7 +706,7 @@ create_gallery (BaconVideoWidget *bvw, const char *input, const char *output)
 		gchar *timestamp_text;
 		gint layout_width, layout_height;
 
-		timestamp_text = totem_time_to_string (pos);
+		timestamp_text = totem_time_to_string (pos * 1000);
 
 		pango_layout_set_text (layout, timestamp_text, -1);
 		pango_layout_get_pixel_size (layout, &layout_width, &layout_height);
@@ -821,9 +814,6 @@ int main (int argc, char *argv[])
 		g_log_set_always_fatal (fatal_mask);
 	}
 
-	if (raw_output == FALSE && output_size == -1)
-		output_size = DEFAULT_OUTPUT_SIZE;
-
 	if (filenames == NULL || g_strv_length (filenames) != 2 ||
 	    (second_index != -1 && gallery != -1) ||
 	    (print_progress == TRUE && verbose == TRUE)) {
